@@ -5,6 +5,8 @@ from openpyxl import \
     Workbook, \
     load_workbook
 
+from domain.power_supply.power_supply_component import PowerSupplyComponent
+from domain.power_supply.power_supply_sheet import PowerSupplySheet
 from xlsx_lib.domain.frame.frame_element import FrameElement
 from xlsx_lib.domain.frame.frame_sheet import FrameSheet
 from xlsx_lib.domain.motorcycle_model.motorcycle_model import MotorcycleModel
@@ -28,6 +30,7 @@ sheetnames_relationships = {
     "ELEC": Sheetnames.ELECTRONIC,
     "PARES APRIETE": Sheetnames.TIGHTENING_TORQUES,
     "CHAS": Sheetnames.FRAME,
+    "ALIM": Sheetnames.POWER_SUPPLY,
 }
 
 
@@ -51,6 +54,7 @@ class MotorcycleModelWorkbook:
         tightening_specifications: Optional[List[SpecificationElement]] = None
         engine_sections: Optional[List[EngineSection]] = None
         frame_elements: Optional[List[FrameElement]] = None
+        power_supply_components: Optional[List[PowerSupplyComponent]] = None
 
         for sheetname in [key for key in workbook.sheetnames
                           if key in sheetnames_relationships]:
@@ -74,6 +78,9 @@ class MotorcycleModelWorkbook:
             elif Sheetnames.FRAME == sheetnames_relationships[sheetname]:
                 frame_elements = FrameSheet(worksheet=workbook[sheetname]).frame_elements
 
+            elif Sheetnames.POWER_SUPPLY == sheetnames_relationships[sheetname]:
+                power_supply_components = PowerSupplySheet(worksheet=workbook[sheetname]).components
+
         self.motorcycle_model = MotorcycleModel(
             model_name=model_name,
             generic_replacements=generic_replacements,
@@ -81,5 +88,6 @@ class MotorcycleModelWorkbook:
             electronic=electronic_elements,
             engine=engine_sections,
             frame=frame_elements,
+            power_supply=power_supply_components,
         )
 
